# WatchMe

![docs/assets/img/logo_small.gif](docs/assets/img/logo_small.gif)

Reproducible watching of web changes. Good for:

 1. Waiting for job postings to change or appear
 2. New content for blogs or personal sites that don't have email / rss / atom feeds
 
WatchMe can watch for changes to an entire page, or a specific section of it.
It's appropriate for research use cases where you want to track changes in one
or more pages over time. Importantly, it's a reproducible setup, as your
watches are stored in a configuration file that can easily be shared with others
to reproduce your watching protocol.

**under development**

## Licenses

This code is licensed under the MPL 2.0 [LICENSE](LICENSE).
